@@ -2407,11 +2407,11 @@ show_overlay_window (MetaScreen *screen,
 #endif
 }
 
-#if 0
 static void
 hide_overlay_window (MetaScreen *screen,
                      Window      cow)
 {
+#ifdef HAVE_COW
   MetaDisplay *display = screen->display;
   XserverRegion region;
 
@@ -2420,8 +2420,8 @@ hide_overlay_window (MetaScreen *screen,
                               cow, ShapeBounding,
                               0, 0, region);
   XFixesDestroyRegion (display->xdisplay, region);
-}
 #endif
+}
 
 static Window
 get_output_window (MetaScreen *screen)
@@ -2544,6 +2544,8 @@ meta_compositor_unmanage_screen (MetaCompositor *compositor,
 
   info = screen->compositor_data;
 
+  hide_overlay_window (screen, info->output);
+
   /* Destroy the windows */
   for (index = info->windows; index; index = index->next) 
     {
@@ -2571,6 +2573,10 @@ meta_compositor_unmanage_screen (MetaCompositor *compositor,
                                   CompositeRedirectManual);
   meta_screen_unset_cm_selection (screen);
 
+#ifdef HAVE_COW
+  XCompositeReleaseOverlayWindow (display->xdisplay, info->output);
+#endif
+
   g_free (info);
   screen->compositor_data = NULL;
 #endif
